@@ -19,7 +19,7 @@ use Version::Compare;
 use Path::Class;
 use ExtUtils::Installed;
 
-our $VERSION = '0.06';
+our $VERSION = '0.062';
 
 =head1 NAME
 
@@ -459,7 +459,7 @@ sub generate_report {
 	    chomp($module_name, $version);
 
 	    if ($version =~ m/[0-9]\.[0-9]+/ ) {
-		say $cpanfile_fh "requires " . $module_name . ", " . $version;
+		say $cpanfile_fh "requires '$module_name', '$version';";
 	    } # else : other case ?
 
 	} else {
@@ -615,8 +615,7 @@ To debug and use these logs :
 For more information on how to configure log level, read
 L<Log::Minimal|Log::Minimal> documentation.
 
-For a simple exemple on how to use it, see 
-L<http://smonff.github.io/blog/2013/09/24/how-to-log-easily-with-log-minimal-and-file-stamped/|This blog post>.
+For a simple exemple on how to use it, see this blog post http://bit.ly/1lJwyX7
 
 =head1 CAVEATS
 
@@ -690,6 +689,8 @@ smonff, C<< <smonff at gmail.com> >>
 
 =item * Nikolay Mishin (mishin) helps to make it more cross-platform
 
+=item * Alexandr Ciornii (chorny) advises on version numbers
+
 =back
 
 =cut
